package com.link.core.util.redisclient;

import com.alibaba.fastjson.JSONObject;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisCluster;
import redis.clients.jedis.JedisPool;
import redis.clients.jedis.ScanParams;
import redis.clients.jedis.ScanResult;
import redis.clients.jedis.Tuple;

public class LinkRedisClusterClient implements LinkRedisClient {
   private static Logger logger = LoggerFactory.getLogger(LinkRedisClusterClient.class);
   private JedisCluster jedisCluster;

   public LinkRedisClusterClient(JedisCluster jedisCluster) {
      this.jedisCluster = jedisCluster;
   }

   public String get(String key) {
      return this.jedisCluster.get(key);
   }

   public String hget(String key, String propertyKey) {
      return this.jedisCluster.hget(key, propertyKey);
   }

   public void close() {
   }

   public Long ttl(String s) {
      return this.jedisCluster.ttl(s);
   }

   public Long expire(String s, Integer tokenExpire) {
      return this.jedisCluster.expire(s, tokenExpire);
   }

   public boolean exists(String loginInfoMapKey) {
      return this.jedisCluster.exists(loginInfoMapKey);
   }

   public List<String> hmget(String loginInfoMapKey, String key) {
      return this.jedisCluster.hmget(loginInfoMapKey, new String[]{key});
   }

   public List<String> hmget(String key, String[] fields) {
      return this.jedisCluster.hmget(key, fields);
   }

   public Long hdel(String loginInfoMapKey, String key) {
      return this.jedisCluster.hdel(loginInfoMapKey, new String[]{key});
   }

   public Long hset(String loginInfoMapKey, String key, String value) {
      return this.jedisCluster.hset(loginInfoMapKey, key, value);
   }

   public String hmset(String mapKey, Map<String, String> map) {
      return this.jedisCluster.hmset(mapKey, map);
   }

   public String set(String key, String value) {
      return this.jedisCluster.set(key, value);
   }

   public String set(String key, String value, String nxxx, String expx, int time) {
      return this.jedisCluster.set(key, value, nxxx, expx, (long)time);
   }

   public List<String> brpop(int i, String key) {
      return this.jedisCluster.brpop(i, key);
   }

   public long llen(String key) {
      return this.jedisCluster.llen(key);
   }

   public Long lpush(String key, String value) {
      return this.jedisCluster.lpush(key, new String[]{value});
   }

   public Long lpush(String key, String... value) {
      return this.jedisCluster.lpush(key, value);
   }

   public Long sadd(String key, String[] value) {
      return this.jedisCluster.sadd(key, value);
   }

   public long scard(String key) {
      return this.jedisCluster.scard(key);
   }

   public String spop(String key) {
      return this.jedisCluster.spop(key);
   }

   public Set<String> keys(String pattern) {
      TreeSet<String> keys = new TreeSet();
      Map<String, JedisPool> clusterNodes = this.jedisCluster.getClusterNodes();
      Iterator var4 = clusterNodes.keySet().iterator();

      while(var4.hasNext()) {
         String k = (String)var4.next();
         Jedis connection = null;

         try {
            JedisPool jp = (JedisPool)clusterNodes.get(k);
            connection = jp.getResource();
            if (!connection.info("replication").contains("role:slave")) {
               keys.addAll(connection.keys(pattern));
            }
         } catch (Exception var11) {
            Exception e = var11;
            throw e;
         } finally {
            if (connection != null) {
               connection.close();
            }

         }
      }

      return keys;
   }

   public Set<byte[]> keys(byte[] pattern) {
      Set<byte[]> bytes = new HashSet();
      Set<String> valueSet = this.keys(new String(pattern));
      Iterator var4 = valueSet.iterator();

      while(var4.hasNext()) {
         String value = (String)var4.next();
         bytes.add(value.getBytes());
      }

      return bytes;
   }

   public Long del(String[] keyStrs) {
      int tmpValue = 0;
      String[] var3 = keyStrs;
      int var4 = keyStrs.length;

      for(int var5 = 0; var5 < var4; ++var5) {
         String key = var3[var5];
         this.del(key);
         ++tmpValue;
      }

      return (long)tmpValue;
   }

   public Long del(String mutexKey) {
      return this.jedisCluster.del(mutexKey);
   }

   public Long del(Set<String> keySet) {
      long tmpValue = 0L;

      for(Iterator<String> iter = keySet.iterator(); iter.hasNext(); ++tmpValue) {
         this.jedisCluster.del((String)iter.next());
      }

      return tmpValue;
   }

   public String setex(String mutexKey, int i, String y) {
      return this.jedisCluster.setex(mutexKey, i, y);
   }

   public String select(int dbIndex) {
      return this.jedisCluster.select(0);
   }

   public Set<String> hkeys(String var1) {
      return this.jedisCluster.hkeys(var1);
   }

   public List<byte[]> mget(byte[][] keys) {
      List<byte[]> bytes = new ArrayList();
      if (keys != null && keys.length > 0) {
         for(int i = 0; i < keys.length; ++i) {
            byte[] byteResult = this.jedisCluster.get(keys[i]);
            bytes.add(byteResult);
         }

         return bytes;
      } else {
         return bytes;
      }
   }

   public List<String> mget(String... keys) {
      List<String> values = new ArrayList(keys.length);
      String[] var3 = keys;
      int var4 = keys.length;

      for(int var5 = 0; var5 < var4; ++var5) {
         String key = var3[var5];
         values.add(this.jedisCluster.get(key));
      }

      return values;
   }

   public Map<String, String> hgetAll(String key) {
      return this.jedisCluster.hgetAll(key);
   }

   public List<String> lrange(String key, long start, long end) {
      return this.jedisCluster.lrange(key, start, end);
   }

   public String ltrim(String key, long start, long end) {
      return this.jedisCluster.ltrim(key, start, end);
   }

   public String lindex(String key, long index) {
      return this.jedisCluster.lindex(key, index);
   }

   public Long pexpire(String key, long milliseconds) {
      return this.jedisCluster.pexpire(key, milliseconds);
   }

   public Long hincrBy(String key, String field, long value) {
      return this.jedisCluster.hincrBy(key, field, value);
   }

   public Double hincrByFloat(String key, String field, double value) {
      return this.jedisCluster.hincrByFloat(key, field, value);
   }

   public Long setnx(String key, String value) {
      return this.jedisCluster.setnx(key, value);
   }

   public String getSet(String key, String value) {
      return this.jedisCluster.getSet(key, value);
   }

   public String rpop(String key) {
      return this.jedisCluster.rpop(key);
   }

   public Boolean scriptExists(String key, String sha1) {
      return this.jedisCluster.scriptExists(key, sha1);
   }

   public String scriptLoad(String script, String key) {
      return this.jedisCluster.scriptLoad(script, key);
   }

   public Object evalsha(String sha1, int keyCount, String... params) {
      return this.jedisCluster.evalsha(sha1, keyCount, params);
   }

   public Boolean hexists(String key, String field) {
      return this.jedisCluster.hexists(key, field);
   }

   public Object eval(String script, List<String> keys, List<String> args) {
      return this.jedisCluster.eval(script, keys, args);
   }

   public List<String> scan(Integer count, String matchKey) {
      List<String> list = new ArrayList();
      Map<String, JedisPool> clusterNodes = this.jedisCluster.getClusterNodes();
      Iterator var5 = clusterNodes.entrySet().iterator();

      while(var5.hasNext()) {
         Map.Entry<String, JedisPool> entry = (Map.Entry)var5.next();
         Jedis jedis = null;

         try {
            jedis = ((JedisPool)entry.getValue()).getResource();
            if (!jedis.info("replication").contains("role:slave")) {
               List<String> keys = getScan(jedis, matchKey, count);
               if (keys.size() > 0) {
                  list.addAll(keys);
               }
            }
         } finally {
            if (jedis != null) {
               jedis.close();
            }

         }
      }

      return list;
   }

   private static List<String> getScan(Jedis redisService, String matchKey, Integer count) {
      List<String> list = new ArrayList();
      ScanParams params = new ScanParams();
      params.match(matchKey);
      params.count(count);
      String cursor = "0";

      do {
         ScanResult<String> scanResult = redisService.scan(cursor, params);
         List<String> elements = scanResult.getResult();
         if (elements != null && elements.size() > 0) {
            list.addAll(elements);
         }

         cursor = scanResult.getStringCursor();
      } while(!"0".equals(cursor));

      return list;
   }

   public List<String> hvals(String key) {
      return this.jedisCluster.hvals(key);
   }

   public Long zrevrank(String key, String member) {
      return this.jedisCluster.zrevrank(key, member);
   }

   public Set<String> zrevrange(String key, long start, long stop) {
      return this.jedisCluster.zrevrange(key, start, stop);
   }

   public Double zscore(String key, String member) {
      return this.jedisCluster.zscore(key, member);
   }

   public Long incrBy(String key, long integer) {
      return this.jedisCluster.incrBy(key, integer);
   }

   public void scanExec(Integer count, String matchKey, RedisScanExec redisScanExec, JSONObject paramJson) throws Exception {
      Map<String, JedisPool> clusterNodes = this.jedisCluster.getClusterNodes();
      Iterator var6 = clusterNodes.entrySet().iterator();

      while(var6.hasNext()) {
         Map.Entry<String, JedisPool> entry = (Map.Entry)var6.next();
         Jedis jedis = null;

         try {
            jedis = ((JedisPool)entry.getValue()).getResource();
            if (!jedis.info("replication").contains("role:slave")) {
               execScan(jedis, matchKey, count, redisScanExec, paramJson);
            }
         } finally {
            if (jedis != null) {
               jedis.close();
            }

         }
      }

   }

   private static void execScan(Jedis redisService, String matchKey, Integer count, RedisScanExec redisScanExec, JSONObject paramJson) throws Exception {
      ScanParams params = new ScanParams();
      params.match(matchKey);
      params.count(count);
      String cursor = "0";

      do {
         ScanResult<String> scanResult = redisService.scan(cursor, params);
         List<String> elements = scanResult.getResult();
         if (elements != null && elements.size() > 0) {
            redisScanExec.redisScanExec(elements, paramJson);
         }

         cursor = scanResult.getStringCursor();
      } while(!"0".equals(cursor));

   }

   public Set<String> smembers(String key) {
      return this.jedisCluster.smembers(key);
   }

   public boolean sismember(String key, String member) {
      return this.jedisCluster.sismember(key, member);
   }

   public Long srem(String key, String... member) {
      return this.jedisCluster.srem(key, member);
   }

   public String type(String key) {
      return this.jedisCluster.type(key);
   }

   public String rename(String oldkey, String newkey) {
      return this.jedisCluster.rename(oldkey, newkey);
   }

   public Long zrem(String key, String... member) {
      return this.jedisCluster.zrem(key, member);
   }

   public Long zadd(String key, double score, String member) {
      return this.jedisCluster.zadd(key, score, member);
   }

   public Long zremrangeByScore(String key, double start, double end) {
      return this.jedisCluster.zremrangeByScore(key, start, end);
   }

   public Double zincrby(String key, double score, String member) {
      return this.jedisCluster.zincrby(key, score, member);
   }

   public Long zcard(String key) {
      return this.jedisCluster.zcard(key);
   }

   public Set<String> zrevrangeByScore(String key, double max, double min) {
      return this.jedisCluster.zrevrangeByScore(key, max, min);
   }

   public Set<String> zrange(String key, long start, long end) {
      return this.jedisCluster.zrange(key, start, end);
   }

   public void info() {
      Map<String, JedisPool> clusterNodes = this.jedisCluster.getClusterNodes();
      Iterator var2 = clusterNodes.keySet().iterator();

      while(var2.hasNext()) {
         String key = (String)var2.next();
         logger.info("key:" + key + "节点信息" + ((JedisPool)clusterNodes.get(key)).getResource().info());
      }

   }

   public Set<Tuple> zrangeByScoreWithScores(String key, double min, double max) {
      return this.jedisCluster.zrangeByScoreWithScores(key, min, max);
   }
}
